﻿#region Copyright (C) 2003-2014 Stimulsoft
/*
{*******************************************************************}
{																	}
{	Stimulsoft Reports.RT											}
{	                         										}
{																	}
{	Copyright (C) 2003-2014 Stimulsoft     							}
{	ALL RIGHTS RESERVED												}
{																	}
{	The entire contents of this file is protected by U.S. and		}
{	International Copyright Laws. Unauthorized reproduction,		}
{	reverse-engineering, and distribution of all or any portion of	}
{	the code contained in this file is strictly prohibited and may	}
{	result in severe civil and criminal penalties and will be		}
{	prosecuted to the maximum extent possible under the law.		}
{																	}
{	RESTRICTIONS													}
{																	}
{	THIS SOURCE CODE AND ALL RESULTING INTERMEDIATE FILES			}
{	ARE CONFIDENTIAL AND PROPRIETARY								}
{	TRADE SECRETS OF Stimulsoft										}
{																	}
{	CONSULT THE END USER LICENSE AGREEMENT FOR INFORMATION ON		}
{	ADDITIONAL RESTRICTIONS.										}
{																	}
{*******************************************************************}
*/
#endregion Copyright (C) 2003-2014 Stimulsoft

using Stimulsoft.Base.Localization;
using Stimulsoft.Controls.RT;
using Stimulsoft.Controls.RT.Controls;
using Stimulsoft.Report.Export;
using Stimulsoft.Report.RT.HelpOnline;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Automation;
using Windows.UI.Xaml.Navigation;

namespace Stimulsoft.Report.Viewer.RT.Export.Native
{
    internal sealed partial class StiPdfExportSetupPage
    {
        public StiPdfExportSetupPage()
        {
            this.InitializeComponent();

            if (Windows.ApplicationModel.DesignMode.DesignModeEnabled) return;
            this.Name = "PdfExportSetupPage";

            headerControl = new StiPageHeader(this);
            headerControl.BackButton.Click += BackButtonClick;
            gridRoot.Children.Insert(0, headerControl);

            Localize();

            checkBoxOpenAfterExport.IsOn = StiSettings.GetBool(this.Name, "OpenAfterExport");
            sliderImageQuality.Value = StiSettings.GetInt(this.Name, "ImageQuality", 100);
            checkBoxStandardPdfFonts.IsOn = StiSettings.GetBool(this.Name, "StandardPdfFonts");
            checkBoxCompressed.IsOn = StiSettings.GetBool(this.Name, "Compressed", true);
        }

        #region Fields

        private readonly StiPageHeader headerControl;
        private StiViewerControl viewerControl;
        private StiPdfExportService exportService;
        private StiReport report;

        #endregion

        #region StiPageBase.override

        protected override void BlockPage(bool useDictionaryPanel)
        {
            appBar.IsEnabled = false;
            scrollViewer.IsEnabled = false;
        }

        protected override void UnblockPage()
        {
            appBar.IsEnabled = true;
            scrollViewer.IsEnabled = true;
        }

        #endregion

        #region Methods

        private void SaveSettings()
        {
            StiSettings.Set(this.Name, "OpenAfterExport", checkBoxOpenAfterExport.IsOn);
            StiSettings.Set(this.Name, "ImageQuality", sliderImageQuality.Value);
            StiSettings.Set(this.Name, "StandardPdfFonts", checkBoxStandardPdfFonts.IsOn);
            StiSettings.Set(this.Name, "Compressed", checkBoxCompressed.IsOn);
        }

        #endregion

        #region Methods.override

        protected override void Localize()
        {
            this.headerControl.Title = StiLocalization.Get("Export", "title");

            groupBoxImageQuality.Text = StiLocalization.Get("Export", "ImageQuality");

            checkBoxStandardPdfFonts.Header = StiLocalization.Get("Export", "StandardPDFFonts");
            checkBoxStandardPdfFonts.OnContent = StiLocalization.Get("FormFormatEditor", "nameOn");
            checkBoxStandardPdfFonts.OffContent = StiLocalization.Get("FormFormatEditor", "nameOff");

            checkBoxCompressed.Header = StiLocalization.Get("Export", "Compressed");
            checkBoxOpenAfterExport.Header = StiLocalization.GetEx("Export", "OpenAfterExport", 7);
            checkBoxOpenAfterExport.OnContent = checkBoxCompressed.OnContent = checkBoxStandardPdfFonts.OnContent;
            checkBoxOpenAfterExport.OffContent = checkBoxCompressed.OffContent = checkBoxStandardPdfFonts.OffContent;

            AutomationProperties.SetName(buttonHelp, StiLocalization.Get("Buttons", "Help"));
            AutomationProperties.SetName(buttonExport, StiLocalization.Get("Buttons", "Export"));
        }

        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            base.OnNavigatedTo(e);

            var pars = (object[])e.Parameter;
            this.viewerControl = (StiViewerControl)pars[0];
            this.exportService = (StiPdfExportService)pars[1];
            this.report = (StiReport)pars[2];
            this.pagesRange.CurrentPage = report.CurrentPrintPage;
        }

        protected override void GoBack()
        {
            viewerControl.rootFrame.GoBack();
        }

        #endregion

        #region Handlers

        private async void buttonHelpClick(object sender, RoutedEventArgs e)
        {
            await StiHelpProvider.ShowHelpViewerAsync("user-manual/exports_formats_with_fixed_page_layout_pdf.htm");
        }

        private void BackButtonClick(object sender, RoutedEventArgs e)
        {
            this.GoBack();
        }

        private async void ButtonExportClick(object sender, RoutedEventArgs e)
        {
            var stream = await exportService.GetFileStream(report.ReportName);
            if (stream == null) return;

            viewerControl.ShowProgressBar();

            var settings = new StiPdfExportSettings
                               {
                                   PageRange = pagesRange.GetPagesRange(),
                                   ImageQuality = (float)(sliderImageQuality.Value / 100d),
                                   StandardPdfFonts = checkBoxStandardPdfFonts.IsOn,
                                   Compressed = checkBoxCompressed.IsOn,
                                   OpenAfterExport = checkBoxOpenAfterExport.IsOn
                               };

            await exportService.ExportPdfAsync(report, stream, settings);

            viewerControl.HideProgressBar();

            SaveSettings();
            GoBack();
        }
        #endregion
    }
}